@@ -151,50 +151,55 @@ class ClusterRandomSampler(Sampler):
     def __len__(self):
         return len(self.data_source)
 
-def collate_fn(batch):
-    filenames = []
-    img = []
-    target_weights = []
-    tgt_input = []
-    max_label_len = max(len(sample['word']) for sample in batch)
-    for sample in batch:
-        img.append(sample['img'])
-        filenames.append(sample['img_path'])
-        label = sample['word']
-        label_len = len(label)
+class Collator(object):
+    def __init__(self, masked_language_model=True):
+        self.masked_language_model = masked_language_model
+
+    def __call__(self, batch):
+        filenames = []
+        img = []
+        target_weights = []
+        tgt_input = []
+        max_label_len = max(len(sample['word']) for sample in batch)
+        for sample in batch:
+            img.append(sample['img'])
+            filenames.append(sample['img_path'])
+            label = sample['word']
+            label_len = len(label)
+            
+            
+            tgt = np.concatenate((
+                label,
+                np.zeros(max_label_len - label_len, dtype=np.int32)))
+            tgt_input.append(tgt)
+
+            one_mask_len = label_len - 1
+
+            target_weights.append(np.concatenate((
+                np.ones(one_mask_len, dtype=np.float32),
+                np.zeros(max_label_len - one_mask_len,dtype=np.float32))))
+            
+        img = np.array(img, dtype=np.float32)
+
+
+        tgt_input = np.array(tgt_input, dtype=np.int64).T
+        tgt_output = np.roll(tgt_input, -1, 0).T
+        tgt_output[:, -1]=0
         
+        # random mask token
+        if self.masked_language_model:
+            mask = np.random.random(size=tgt_input.shape) < 0.05
+            mask = mask & (tgt_input != 0) & (tgt_input != 1) & (tgt_input != 2)
+            tgt_input[mask] = 3
+
+        tgt_padding_mask = np.array(target_weights)==0
+
+        rs = {
+            'img': torch.FloatTensor(img),
+            'tgt_input': torch.LongTensor(tgt_input),
+            'tgt_output': torch.LongTensor(tgt_output),
+            'tgt_padding_mask': torch.BoolTensor(tgt_padding_mask),
+            'filenames': filenames
+        }   
         
-        tgt = np.concatenate((
-            label,
-            np.zeros(max_label_len - label_len, dtype=np.int32)))
-        tgt_input.append(tgt)
-
-        one_mask_len = label_len - 1
-
-        target_weights.append(np.concatenate((
-            np.ones(one_mask_len, dtype=np.float32),
-            np.zeros(max_label_len - one_mask_len,dtype=np.float32))))
-        
-    img = np.array(img, dtype=np.float32)
-
-
-    tgt_input = np.array(tgt_input, dtype=np.int64).T
-    tgt_output = np.roll(tgt_input, -1, 0).T
-    tgt_output[:, -1]=0
-    
-    # random mask token
-    mask = np.random.random(size=tgt_input.shape) < 0.05
-    mask = mask & (tgt_input != 0) & (tgt_input != 1) & (tgt_input != 2)
-    tgt_input[mask] = 3
-
-    tgt_padding_mask = np.array(target_weights)==0
-
-    rs = {
-        'img': torch.FloatTensor(img),
-        'tgt_input': torch.LongTensor(tgt_input),
-        'tgt_output': torch.LongTensor(tgt_output),
-        'tgt_padding_mask': torch.BoolTensor(tgt_padding_mask),
-        'filenames': filenames
-    }   
-    
-    return rs
+        return rs
