@@ -42,9 +42,9 @@ class Vgg(nn.Module):
         conv = conv.permute(-1, 0, 1)
         return conv
 
-def vgg11_bn(ss, ks, hidden):
-    return Vgg('vgg11_bn', ss, ks, hidden)
+def vgg11_bn(ss, ks, hidden, pretrained=True, dropout=0.5):
+    return Vgg('vgg11_bn', ss, ks, hidden, pretrained, dropout)
 
-def vgg19_bn(ss, ks, hidden):
-    return Vgg('vgg19_bn', ss, ks, hidden)
+def vgg19_bn(ss, ks, hidden, pretrained=True, dropout=0.5):
+    return Vgg('vgg19_bn', ss, ks, hidden, pretrained, dropout)
    
