@@ -10,8 +10,8 @@ from vietocr.loader.aug import ImgAugTransform
 
 import yaml
 import torch
-from vietocr.loader.DataLoader import DataGen
-from vietocr.loader.dataloader import OCRDataset, ClusterRandomSampler, collate_fn
+from vietocr.loader.dataloader_v1 import DataGen
+from vietocr.loader.dataloader import OCRDataset, ClusterRandomSampler, Collator
 from torch.utils.data import DataLoader
 from einops import rearrange
 from torch.optim.lr_scheduler import CosineAnnealingLR, CyclicLR, OneCycleLR
@@ -26,7 +26,7 @@ import matplotlib.pyplot as plt
 import time
 
 class Trainer():
-    def __init__(self, config, pretrained=True):
+    def __init__(self, config, pretrained=True, augmentor=ImgAugTransform()):
 
         self.config = config
         self.model, self.vocab = build_model(config)
@@ -43,6 +43,9 @@ class Trainer():
         self.batch_size = config['trainer']['batch_size']
         self.print_every = config['trainer']['print_every']
         self.valid_every = config['trainer']['valid_every']
+        
+        self.image_aug = config['aug']['image_aug']
+        self.masked_language_model = config['aug']['masked_language_model']
 
         self.checkpoint = config['trainer']['checkpoint']
         self.export_weights = config['trainer']['export']
@@ -68,13 +71,15 @@ class Trainer():
 
         self.criterion = LabelSmoothingLoss(len(self.vocab), padding_idx=self.vocab.pad, smoothing=0.1)
         
-        transforms = ImgAugTransform()
+        transforms = None
+        if self.image_aug:
+            transforms =  augmentor
 
         self.train_gen = self.data_gen('train_{}'.format(self.dataset_name), 
-                self.data_root, self.train_annotation, transform=transforms)
+                self.data_root, self.train_annotation, self.masked_language_model, transform=transforms)
         if self.valid_annotation:
             self.valid_gen = self.data_gen('valid_{}'.format(self.dataset_name), 
-                    self.data_root, self.valid_annotation)
+                    self.data_root, self.valid_annotation, masked_language_model=False)
 
         self.train_losses = []
         
@@ -167,8 +172,9 @@ class Trainer():
 
             if self.beamsearch:
                 translated_sentence = batch_translate_beam_search(batch['img'], self.model)
+                prob = None
             else:
-                translated_sentence = translate(batch['img'], self.model)
+                translated_sentence, prob = translate(batch['img'], self.model)
 
             pred_sent = self.vocab.batch_decode(translated_sentence.tolist())
             actual_sent = self.vocab.batch_decode(batch['tgt_output'].tolist())
@@ -181,11 +187,11 @@ class Trainer():
             if sample != None and len(pred_sents) > sample:
                 break
 
-        return pred_sents, actual_sents, img_files
+        return pred_sents, actual_sents, img_files, prob
 
     def precision(self, sample=None):
 
-        pred_sents, actual_sents, _ = self.predict(sample=sample)
+        pred_sents, actual_sents, _, _ = self.predict(sample=sample)
 
         acc_full_seq = compute_accuracy(actual_sents, pred_sents, mode='full_sequence')
         acc_per_char = compute_accuracy(actual_sents, pred_sents, mode='per_char')
@@ -194,7 +200,7 @@ class Trainer():
     
     def visualize_prediction(self, sample=16, errorcase=False, fontname='serif', fontsize=16):
         
-        pred_sents, actual_sents, img_files = self.predict(sample)
+        pred_sents, actual_sents, img_files, probs = self.predict(sample)
 
         if errorcase:
             wrongs = []
@@ -205,7 +211,7 @@ class Trainer():
             pred_sents = [pred_sents[i] for i in wrongs]
             actual_sents = [actual_sents[i] for i in wrongs]
             img_files = [img_files[i] for i in wrongs]
-
+            probs = [probs[i] for i in wrongs]
 
         img_files = img_files[:sample]
 
@@ -218,11 +224,12 @@ class Trainer():
             img_path = img_files[vis_idx]
             pred_sent = pred_sents[vis_idx]
             actual_sent = actual_sents[vis_idx]
+            prob = probs[vis_idx]
 
             img = Image.open(open(img_path, 'rb'))
             plt.figure()
             plt.imshow(img)
-            plt.title('pred: {} - actual: {}'.format(pred_sent, actual_sent), loc='left', fontdict=fontdict)
+            plt.title('prob: {:.3f} - pred: {} - actual: {}'.format(prob, pred_sent, actual_sent), loc='left', fontdict=fontdict)
             plt.axis('off')
 
         plt.show()
@@ -299,7 +306,7 @@ class Trainer():
 
         return batch
 
-    def data_gen(self, lmdb_path, data_root, annotation, transform=None):
+    def data_gen(self, lmdb_path, data_root, annotation, masked_language_model=True, transform=None):
         dataset = OCRDataset(lmdb_path=lmdb_path, 
                 root_dir=data_root, annotation_path=annotation, 
                 vocab=self.vocab, transform=transform, 
@@ -308,6 +315,8 @@ class Trainer():
                 image_max_width=self.config['dataset']['image_max_width'])
 
         sampler = ClusterRandomSampler(dataset, self.batch_size, True)
+        collate_fn = Collator(masked_language_model)
+
         gen = DataLoader(
                 dataset,
                 batch_size=self.batch_size, 
