@@ -2,13 +2,13 @@ import yaml
 from vietocr.tool.utils import download_config
 
 url_config = {
-        'vgg_transformer':'1TF8effeufpgkHqQFlmNWKsQtCMfDiooa',
-        'resnet_transformer':'1GGhQqtMz4WloBh38U4sMlzLN6cpw5iag',
-        'resnet_fpn_transformer':'1I3-m8wfVpsro1c3UupwxW97MYmP5evvh',
-        'vgg_seq2seq':'1lWUvdYnyZ6HI52I6THS_Zr97YwEzcROn',
-        'vgg_convseq2seq':'1f5On-N-Dc25LZq0ZHLR3uhNlHVPkXl60',
-        'vgg_decoderseq2seq':'10YrSoK_gFuuhTN_u6emOgYEu5v7Y4ksG',
-        'base':'1xiw7ZnT3WH_9HXoGpLbhW-m2Sm2nlthi',
+        'vgg_transformer':'vgg-transformer.yml',
+        'resnet_transformer':'resnet_transformer.yml',
+        'resnet_fpn_transformer':'resnet_fpn_transformer.yml',
+        'vgg_seq2seq':'vgg-seq2seq.yml',
+        'vgg_convseq2seq':'vgg_convseq2seq.yml',
+        'vgg_decoderseq2seq':'vgg_decoderseq2seq.yml',
+        'base':'base.yml',
         }
 
 class Cfg(dict):
