@@ -2,7 +2,8 @@ import os
 import gdown
 import yaml
 import numpy as np
-
+import uuid
+import requests
 
 def download_weights(id_or_url, cached=None, md5=None, quiet=False):
     if id_or_url.startswith('http'):
@@ -14,13 +15,9 @@ def download_weights(id_or_url, cached=None, md5=None, quiet=False):
 
 
 def download_config(id):
-    url = 'https://drive.google.com/uc?id={}'.format(id)
-    output = gdown.download(url, quiet=True)
-    
-    with open(output, encoding='utf-8') as f:
-        config = yaml.safe_load(f)
-    os.remove(output)
-
+    url = 'https://raw.githubusercontent.com/pbcquoc/vietocr/master/config/{}'.format(id)
+    r = requests.get(url)
+    config = yaml.safe_load(r.text)
     return config
 
 def compute_accuracy(ground_truth, predictions, mode='full_sequence'):
